# Test Data

The files in this directory are used for running the tests.  Don't try to use
the public & private keys here, eh? 🍁


## An explanation regarding the naming convention:

* `test.<extension>`: A plain file, untouched by Aletheia
* `test-signed.<extension>`: A copy of the original, successfully signed.
* `test-bad-signature.<extension>`: A copy of the original, signed with a
  signature that looks like it could be legit, but isn't.
* `test-broken-signature.<extension>`: A copy of the original, with malformed
  data in the signature.


## Attributions

* Webm, MP4, and OGV files are courtesy of [TechSlides](http://techslides.com/sample-webm-ogg-and-mp4-video-files-for-html5)

